@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 from abc import abstractmethod
 
-from numpy import eye, shape
+from numpy import eye, shape, ndarray
 from numpy.linalg import pinv
 
 
@@ -9,18 +11,18 @@ class Kernel(object):
         pass
 
     @abstractmethod
-    def kernel(self, X, Y=None):
+    def kernel(self, X: ndarray, Y: ndarray | None = None):
         raise NotImplementedError()
 
     @staticmethod
-    def centering_matrix(n):
+    def centering_matrix(n: int):
         """
         Returns the centering matrix eye(n) - 1.0 / n
         """
         return eye(n) - 1.0 / n
 
     @staticmethod
-    def center_kernel_matrix(K):
+    def center_kernel_matrix(K: ndarray):
         """
         Centers the kernel matrix via a centering matrix H=I-1/n and returns HKH
         """
@@ -28,7 +30,7 @@ class Kernel(object):
         H = eye(n) - 1.0 / n
         return H.dot(K.dot(H))
 
-    def center_kernel_matrix_regression(K, Kz, epsilon):
+    def center_kernel_matrix_regression(K: ndarray, Kz: ndarray, epsilon: float):
         """
         Centers the kernel matrix via a centering matrix R=I-Kz(Kz+\epsilonI)^{-1} and returns RKR
         """
